@@ -17,6 +17,12 @@
 #include "session.h"
 
 
+SSL_CTX *ssl3ctx, *ssl23ctx, *tls1ctx;
+#if OPENSSL_VERSION_NUMBER >= 0x01000100fL
+SSL_CTX *tls11ctx, *tls12ctx;
+#endif
+
+
 /*
  * Connect to mail server.
  */
@@ -85,18 +91,28 @@ open_secure_connection(session *ssn)
 {
 	int r, e;
 	SSL_CTX *ctx;
-	const SSL_METHOD *method;
 
-	method = NULL;
-
-	if (ssn->sslproto && (!strncasecmp(ssn->sslproto, "ssl3", 4) ||
-	    !strncasecmp(ssn->sslproto, "ssl2", 4)))
-		method = SSLv23_client_method();
-	else
-		method = TLSv1_client_method();
-
-	if (!(ctx = SSL_CTX_new(method)))
-		goto fail;
+	if (!ssn->sslproto) {
+		ctx = ssl23ctx;
+	} else if (!strcasecmp(ssn->sslproto, "ssl3")) {
+		ctx = ssl3ctx;
+	} else if (!strcasecmp(ssn->sslproto, "tls1")) {
+		ctx = tls1ctx;
+	} else if (!strcasecmp(ssn->sslproto, "tls1.1")) {
+#if OPENSSL_VERSION_NUMBER >= 0x01000100fL
+		ctx = tls11ctx;
+#else
+		ctx = tls1ctx;
+#endif
+	} else if (!strcasecmp(ssn->sslproto, "tls1.2")) {
+#if OPENSSL_VERSION_NUMBER >= 0x01000100fL
+		ctx = tls12ctx;
+#else
+		ctx = tls1ctx;
+#endif
+	} else {
+		ctx = ssl23ctx;
+	}
 
 	if (!(ssn->sslconn = SSL_new(ctx)))
 		goto fail;
@@ -144,13 +160,10 @@ open_secure_connection(session *ssn)
 	if (get_option_boolean("certificates") && get_cert(ssn) == -1)
 		goto fail;
 
-	SSL_CTX_free(ctx);
-
 	return 0;
 
 fail:
 	ssn->sslconn = NULL;
-	SSL_CTX_free(ctx);
 
 	return -1;
 }
